@@ -19,6 +19,7 @@ DATA_TYPE_EID = enums.AttId.datatypeeid
 
 METRO_PME = enums.DataTypeId.metropme
 TOMTOM_FCD = enums.DataTypeId.tomtomfcd
+KARRUS_RD = enums.DataTypeId.karrusrd
 ROADS = enums.DataTypeId.roads
 ZONES = enums.DataTypeId.zones
 
@@ -27,7 +28,7 @@ MAPPING_ROADS_DATA_POINTS = enums.DataTypeId.mappingroadsdatapoints
 
 
 class RpcClient:
-    samplings = {METRO_PME: 1*60, TOMTOM_FCD: 1*60}
+    samplings = {KARRUS_RD: 5*60, METRO_PME: 1*60, TOMTOM_FCD: 1*60}
 
     def __init__(self, logger, futures=None, callbacks=None):
         if futures is None:
