@@ -12,10 +12,17 @@ DATA_FILE_STRUCT = '%H-%M.csv.bz2'
 
 
 async def write_data(basepath, data, datatype, datadate):
-    loop = asyncio.get_event_loop()
-    with ProcessPoolExecutor() as pool:
-        data = await loop.run_in_executor(pool, bz2.compress, *(data,))
-    await filesystem.write_data(basepath, DATA_FILE_STRUCT, data, datatype, datadate)
+    success = False
+    try:
+        loop = asyncio.get_event_loop()
+        with ProcessPoolExecutor() as pool:
+            data = await loop.run_in_executor(pool, bz2.compress, *(data,))
+        await filesystem.write_data(basepath, DATA_FILE_STRUCT, data, datatype, datadate)
+        success = True
+    except:
+        pass
+    finally:
+        return success
 
 
 async def get_data(datatype, fromdate, todate, basepath, freq=1, window=0):
