@@ -6,7 +6,7 @@ from concurrent.futures import ProcessPoolExecutor
 import json
 import io
 
-from gv_services.proto.archivist_pb2 import TrafficData
+from gv_services.proto.archivist_pb2 import DataQuality, TrafficData
 from gv_services.proto.geographer_pb2 import FreeflowSpeeds, Locations, Mapping
 from gv_utils import csv, enums, geometry
 import shapely.wkt
@@ -57,6 +57,29 @@ def _csv_loads_bytes(pbtrafficdata):
     return data
 
 
+async def encode_data_quality(dataquality):
+    loop = asyncio.get_event_loop()
+    with ProcessPoolExecutor() as executor:
+        bdata = await loop.run_in_executor(executor, _encode_data_quality, dataquality)
+    return DataQuality(dataquality=bdata)
+
+
+def _encode_data_quality(dataquality):
+    try:
+        bdata = json.dumps(dataquality).encode(csv.ENCODING)
+    except:
+        bdata = b''
+    return bdata
+
+
+def sync_decode_data_quality(pbdataquality):
+    return _decode_data_quality(pbdataquality)
+
+
+def _decode_data_quality(pbdataquality):
+    return json.loads(pbdataquality.dataquality.decode(csv.ENCODING))
+
+
 async def encode_locations(locations):
     loop = asyncio.get_event_loop()
     with ProcessPoolExecutor() as executor:
